@@ -1,8 +1,9 @@
+from __future__ import annotations
 import filecmp
 import json
 from pathlib import Path
 from types import TracebackType
-from typing import Dict, List, Optional, Type
+from typing import Optional
 import pytest
 from pytest_mock import MockerFixture
 import requests
@@ -12,6 +13,7 @@ from pypi_simple import (
     DistributionPackage,
     IndexPage,
     NoDigestsError,
+    NoSuchProjectError,
     ProgressTracker,
     ProjectPage,
     PyPISimple,
@@ -86,7 +88,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -101,7 +104,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -116,7 +120,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -131,7 +136,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -146,7 +152,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4",
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -161,7 +168,8 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
                     },
                     requires_python=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4",
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -171,7 +179,14 @@ def test_session(mocker: MockerFixture, content_type: str) -> None:
         )
         (call,) = spy.call_args_list
         assert call[1]["timeout"] == 2.718
-        assert simple.get_project_page("nonexistent") is None
+        with pytest.raises(NoSuchProjectError) as excinfo:
+            simple.get_project_page("nonexistent")
+        assert excinfo.value.project == "nonexistent"
+        assert excinfo.value.url == "https://test.nil/simple/nonexistent/"
+        assert str(excinfo.value) == (
+            "No details about project 'nonexistent' available at"
+            " https://test.nil/simple/nonexistent/"
+        )
 
 
 @responses.activate
@@ -202,7 +217,8 @@ def test_project_hint_received() -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -217,7 +233,8 @@ def test_project_hint_received() -> None:
                     },
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -276,7 +293,8 @@ def test_redirected_project_page() -> None:
                     digests={},
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -319,7 +337,8 @@ def test_utf8_declarations(content_type: str, body_decl: bytes) -> None:
                     digests={},
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -365,7 +384,8 @@ def test_latin2_declarations(content_type: str, body_decl: bytes) -> None:
                     digests={},
                     requires_python=None,
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=False,
                 ),
@@ -435,6 +455,28 @@ def test_stream_project_names(mocker: MockerFixture) -> None:
         assert call[1]["timeout"] == 1.618
 
 
+@responses.activate
+def test_stream_project_names_json() -> None:
+    responses.add(
+        method=responses.GET,
+        url="https://test.nil/simple/",
+        json={
+            "meta": {"_last-serial": 14267765, "api-version": "1.0"},
+            "projects": [{"name": "argset"}, {"name": "banana"}, {"name": "coconut"}],
+        },
+        content_type="application/vnd.pypi.simple.v1+json",
+        headers={"x-pypi-last-serial": "12345"},
+    )
+    responses.add(
+        method=responses.GET,
+        url="https://test.nil/simple/",
+        body="This URL should only be requested once.",
+        status=500,
+    )
+    with PyPISimple("https://test.nil/simple/") as simple:
+        assert list(simple.stream_project_names()) == ["argset", "banana", "coconut"]
+
+
 @responses.activate
 def test_json_session(mocker: MockerFixture) -> None:
     responses.add(
@@ -489,7 +531,8 @@ def test_json_session(mocker: MockerFixture) -> None:
                     url="https://files.pythonhosted.org/packages/b5/2b/7aa284f345e37f955d86e4cd57b1039b573552b0fc29d1a522ec05c1ee41/argset-0.1.0-py3-none-any.whl",
                     requires_python="~=3.6",
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=None,
                     digests={
@@ -504,7 +547,8 @@ def test_json_session(mocker: MockerFixture) -> None:
                     url="https://files.pythonhosted.org/packages/d0/ee/1c25e68d029e8daaf3228dababbf3261fa5d9569f6f705867b2ad4df9b6d/argset-0.1.0.tar.gz",
                     requires_python="~=3.6",
                     has_sig=None,
-                    yanked=None,
+                    is_yanked=False,
+                    yanked_reason=None,
                     metadata_digests=None,
                     has_metadata=None,
                     digests={
@@ -517,7 +561,14 @@ def test_json_session(mocker: MockerFixture) -> None:
         )
         (call,) = spy.call_args_list
         assert call[1]["timeout"] == 2.718
-        assert simple.get_project_page("nonexistent") is None
+        with pytest.raises(NoSuchProjectError) as excinfo:
+            simple.get_project_page("nonexistent")
+        assert excinfo.value.project == "nonexistent"
+        assert excinfo.value.url == "https://test.nil/simple/nonexistent/"
+        assert str(excinfo.value) == (
+            "No details about project 'nonexistent' available at"
+            " https://test.nil/simple/nonexistent/"
+        )
 
 
 @responses.activate
@@ -576,7 +627,8 @@ def test_download(tmp_path: Path) -> None:
             },
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
@@ -605,7 +657,8 @@ def test_download_no_digests(tmp_path: Path) -> None:
             digests={},
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
@@ -636,7 +689,8 @@ def test_download_bad_digests(tmp_path: Path) -> None:
             },
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
@@ -672,7 +726,8 @@ def test_download_bad_digests_keep(tmp_path: Path) -> None:
             },
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
@@ -698,7 +753,7 @@ def test_download_bad_digests_keep(tmp_path: Path) -> None:
 )
 @responses.activate
 def test_download_bad_digests_no_verify(
-    tmp_path: Path, digests: Dict[str, str]
+    tmp_path: Path, digests: dict[str, str]
 ) -> None:
     responses.add(
         method=responses.GET,
@@ -716,7 +771,8 @@ def test_download_bad_digests_no_verify(
             digests=digests,
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
@@ -731,15 +787,15 @@ class SpyingProgressTracker:
         self.content_length: Optional[int] = None
         self.enter_called = False
         self.exit_called = False
-        self.updates: List[int] = []
+        self.updates: list[int] = []
 
-    def __enter__(self) -> "SpyingProgressTracker":
+    def __enter__(self) -> SpyingProgressTracker:
         self.enter_called = True
         return self
 
     def __exit__(
         self,
-        _exc_type: Optional[Type[BaseException]],
+        _exc_type: Optional[type[BaseException]],
         _exc_val: Optional[BaseException],
         _exc_tb: Optional[TracebackType],
     ) -> None:
@@ -771,7 +827,8 @@ def test_download_progress(tmp_path: Path) -> None:
             },
             requires_python=None,
             has_sig=None,
-            yanked=None,
+            is_yanked=False,
+            yanked_reason=None,
             metadata_digests=None,
             has_metadata=False,
         )
