@@ -1,3 +1,4 @@
+from datetime import datetime, timezone
 import json
 from pathlib import Path
 import pytest
@@ -630,6 +631,57 @@ def test_from_json_data_empty() -> None:
                 last_serial="10562871",
             ),
         ),
+        (
+            "argset-700.json",
+            ProjectPage(
+                project="argset",
+                packages=[
+                    DistributionPackage(
+                        filename="argset-0.1.0-py3-none-any.whl",
+                        project="argset",
+                        version="0.1.0",
+                        package_type="wheel",
+                        url="https://files.pythonhosted.org/packages/b5/2b/7aa284f345e37f955d86e4cd57b1039b573552b0fc29d1a522ec05c1ee41/argset-0.1.0-py3-none-any.whl",
+                        requires_python="~=3.6",
+                        has_sig=None,
+                        is_yanked=False,
+                        yanked_reason=None,
+                        metadata_digests=None,
+                        has_metadata=None,
+                        digests={
+                            "sha256": "107a632c7112faceb9fd6e93658dd461154713db250f7ffde5bd473e17cf1db5"
+                        },
+                        size=5219,
+                        upload_time=datetime(
+                            2021, 6, 5, 0, 15, 37, 534150, tzinfo=timezone.utc
+                        ),
+                    ),
+                    DistributionPackage(
+                        filename="argset-0.1.0.tar.gz",
+                        project="argset",
+                        version="0.1.0",
+                        package_type="sdist",
+                        url="https://files.pythonhosted.org/packages/d0/ee/1c25e68d029e8daaf3228dababbf3261fa5d9569f6f705867b2ad4df9b6d/argset-0.1.0.tar.gz",
+                        requires_python="~=3.6",
+                        has_sig=None,
+                        is_yanked=False,
+                        yanked_reason=None,
+                        metadata_digests=None,
+                        has_metadata=None,
+                        digests={
+                            "sha256": "8a41ee4789d37517c259984c11f2aa3639a90dc8fa446ff905ecc5fe6623c12d"
+                        },
+                        size=6565,
+                        upload_time=datetime(
+                            2021, 6, 5, 0, 15, 39, 3726, tzinfo=timezone.utc
+                        ),
+                    ),
+                ],
+                repository_version="1.0",
+                last_serial="10562871",
+                versions=["0.1.0"],
+            ),
+        ),
         (
             "yanked.json",
             ProjectPage(
